@@ -1,4 +1,5 @@
 from .telemetry import Telemetry
+from datetime import datetime
 import argparse
 import yaml
 
@@ -12,11 +13,12 @@ def get_keys(path):
     return keys
 
 def main():
+    logname = datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
     parser = argparse.ArgumentParser()
 
     parser.add_argument('--config', default='config.yaml',
                         help='Relative path to the config file')
-    parser.add_argument('--log', default='log.csv',
+    parser.add_argument('--log', default=logname,
                         help='Relative path for the output log file')
     parser.add_argument('--interval', default=1.0,
                         help='Polling interval in seconds')
